@@ -162,7 +162,7 @@ def find_group_cohorts(labels, chunks, merge=True, method="cohorts"):
     labels = np.asarray(labels)
 
     if method == "split-reduce":
-        return _get_expected_groups(labels, sort=False).values.reshape(-1, 1).tolist()
+        return list(_get_expected_groups(labels, sort=False).to_numpy().reshape(-1, 1))
 
     # Build an array with the shape of labels, but where every element is the "chunk number"
     # 1. First subset the array appropriately
@@ -462,7 +462,7 @@ def factorize_(
         group_idx = factorized[0]
 
     if fastpath:
-        return group_idx, found_groups, grp_shape
+        return group_idx.reshape(by[0].shape), found_groups, grp_shape
 
     if np.isscalar(axis) and groupvar.ndim > 1:
         # Not reducing along all dimensions of by
@@ -1225,7 +1225,7 @@ def dask_groupby_agg(
         if method == "map-reduce":
             if expected_groups is None:
                 expected_groups = _get_expected_groups(by_input, sort=sort)
-            groups = (expected_groups.values,)
+            groups = (expected_groups.to_numpy(),)
         else:
             groups = (np.concatenate(groups_in_block),)
 
@@ -1548,12 +1548,12 @@ def groupby_reduce(
         # overwrite than when min_count is set
         fill_value = np.nan
 
-    kwargs = dict(axis=axis, fill_value=fill_value, engine=engine, sort=sort)
+    kwargs = dict(axis=axis, fill_value=fill_value, engine=engine)
     agg = _initialize_aggregation(func, array.dtype, fill_value, min_count, finalize_kwargs)
 
     if not has_dask:
         results = _reduce_blockwise(
-            array, by, agg, expected_groups=expected_groups, reindex=reindex, **kwargs
+            array, by, agg, expected_groups=expected_groups, reindex=reindex, sort=sort, **kwargs
         )
         groups = (results["groups"],)
         result = results[agg.name]
@@ -1566,7 +1566,7 @@ def groupby_reduce(
         if kwargs["fill_value"] is None:
             kwargs["fill_value"] = agg.fill_value[agg.name]
 
-        partial_agg = partial(dask_groupby_agg, agg=agg, split_out=split_out, **kwargs)
+        partial_agg = partial(dask_groupby_agg, split_out=split_out, **kwargs)
 
         if method in ["split-reduce", "cohorts"]:
             cohorts = find_group_cohorts(
@@ -1585,15 +1585,14 @@ def groupby_reduce(
                     array_subset = np.take(array_subset, idxr, axis=ax)
                 numblocks = np.prod([len(array_subset.chunks[ax]) for ax in axis])
 
-                # First deep copy becasue we might be doping blockwise,
-                # which sets agg.finalize=None, then map-reduce (GH102)
-                agg = copy.deepcopy(agg)
-
                 # get final result for these groups
                 r, *g = partial_agg(
                     array_subset,
                     by[np.ix_(*indexer)],
                     expected_groups=pd.Index(cohort),
+                    # First deep copy becasue we might be doping blockwise,
+                    # which sets agg.finalize=None, then map-reduce (GH102)
+                    agg=copy.deepcopy(agg),
                     # reindex to expected_groups at the blockwise step.
                     # this approach avoids replacing non-cohort members with
                     # np.nan or some other sentinel value, and preserves dtypes
@@ -1619,6 +1618,7 @@ def groupby_reduce(
                 array,
                 by,
                 expected_groups=None if method == "blockwise" else expected_groups,
+                agg=agg,
                 reindex=reindex,
                 method=method,
                 sort=sort,
