@@ -62,7 +62,7 @@ def xarray_reduce(
     fill_value=None,
     method: str = "map-reduce",
     engine: str = "flox",
-    keep_attrs: bool = True,
+    keep_attrs: bool | None = True,
     skipna: bool | None = None,
     min_count: int | None = None,
     reindex: bool | None = None,
@@ -181,6 +181,10 @@ def xarray_reduce(
         if isinstance(b, xr.DataArray) and b.name is None:
             raise ValueError("Cannot group by unnamed DataArrays.")
 
+    # TODO: move to GroupBy._flox_reduce
+    if keep_attrs is None:
+        keep_attrs = True
+
     if isinstance(isbin, bool):
         isbin = (isbin,) * len(by)
     if expected_groups is None:
@@ -241,7 +245,7 @@ def xarray_reduce(
         raise ValueError(f"Cannot reduce over absent dimensions {dim}.")
 
     dims_not_in_groupers = tuple(d for d in dim if d not in grouper_dims)
-    if dims_not_in_groupers == dim and not any(isbin):
+    if dims_not_in_groupers == tuple(dim) and not any(isbin):
         # reducing along a dimension along which groups do not vary
         # This is really just a normal reduction.
         # This is not right when binning so we exclude.
